pytilities.test.testall

Package pytilities :: Package test :: Module testall |
[hide private]
[frames] | no frames]

# Module testall

source code

Functions | [hide private]
run() | source code

Variables | [hide private]
| test_suite = `<unittest.TestSuite tests=[<unittest.TestSuite te`...``
| __package__ = ``'``pytilities.test``'``

Variables Details | [hide private]

  ### test_suite Value:
      <unittest.TestSuite tests=[<unittest.TestSuite tests=[<unittest.TestSu
      ite tests=[<unittest.TestSuite tests=[]>, <unittest.TestSuite tests=[<
      unittest.TestSuite tests=[<pytilities.event.test.decorators.BDispatche
      rTestCase testMethod=test_success>]>, <unittest.TestSuite tests=[]>, <
      unittest.TestSuite tests=[<pytilities.event.test.decorators.Dispatcher
      TestCase testMethod=test_success>]>, <unittest.TestSuite tests=[<pytil
      ities.event.test.decorators.SwitchTestCase testMethod=test_success>]>]
      >, <unittest.TestSuite tests=[<unittest.TestSuite tests=[<pytilities.e
      ...